/*
//
//       Elvees Performance Platform
//          types and definitions
//
*/

#pragma once

#include <float.h>
#include <stdint.h>
#include <stddef.h>

#ifdef __cplusplus
extern "C" {
#endif


typedef uint8_t    epp_u8;
typedef int8_t     epp_s8;
typedef uint16_t   epp_u16;
typedef int16_t    epp_s16;
typedef uint32_t   epp_u32;
typedef int32_t    epp_s32;
typedef uint64_t   epp_u64;
typedef int64_t    epp_s64;
typedef float      epp_f32;
typedef int16_t    epp_f16;
typedef double     epp_f64;
typedef size_t     epp_size;
typedef uintptr_t  epp_uptr;
typedef uint8_t    epp_bool;


#define EPPAPI( type, name, arg )  type name arg;
#define EPPINL( type, name, arg )  static __inline__ type name arg

#define EPP_MIN_S8     INT8_MIN
#define EPP_MAX_S8     INT8_MAX
#define EPP_MIN_U8     0
#define EPP_MAX_U8     UINT8_MAX
#define EPP_MIN_S16    INT16_MIN
#define EPP_MAX_S16    INT16_MAX
#define EPP_MIN_U16    0
#define EPP_MAX_U16    UINT16_MAX
#define EPP_MIN_S32    INT32_MIN
#define EPP_MAX_S32    INT32_MAX
#define EPP_MIN_U32    0
#define EPP_MAX_U32    UINT32_MAX
#define EPP_MIN_S64    INT64_MIN
#define EPP_MAX_S64    INT64_MAX
#define EPP_MIN_U64    0
#define EPP_MAX_U64    UINT64_MAX
#define EPP_MINABS_F32 FLT_MIN
#define EPP_MAXABS_F32 FLT_MAX
#define EPP_MINABS_F64 DBL_MIN
#define EPP_MAXABS_F64 DBL_MAX
#define EPP_MINABS_F16 ( 6.103515625e-05f )
#define EPP_MAXABS_F16 ( 65504.0f )
#define EPP_MIN_SIZE   0
#define EPP_MAX_SIZE   SIZE_MAX

#define EPP_TRUE   1
#define EPP_FALSE  0

// powers of 2 of type sizes
#define EPP_U8_P2    0
#define EPP_S8_P2    0
#define EPP_U16_P2   1
#define EPP_S16_P2   1
#define EPP_U32_P2   2
#define EPP_S32_P2   2
#define EPP_U64_P2   3
#define EPP_S64_P2   3
#define EPP_F16_P2   1
#define EPP_F32_P2   2
#define EPP_F64_P2   3
#define EPP_CS16_P2  2
#define EPP_CS32_P2  3
#define EPP_CF16_P2  2
#define EPP_CF32_P2  3
#define EPP_CF64_P2  4

#define EPP_PI    ( 3.14159265358979323846 )
#define EPP_2PI   ( EPP_PI * 2.0 )
#define EPP_PI2   ( EPP_PI * 0.5 )
#define EPP_E     ( 2.71828182845904523536 )
#define EPP_DEG_TO_RAD( deg ) ( (deg) / 180.0 * EPP_PI )
#define EPP_RAD_TO_DEG( rad ) ( (rad) * 180.0 / EPP_PI )

#define EPP_ALIGNED_PTR( ptr, align ) (void*)(((epp_uptr)(ptr) + (align) - 1) & ~((epp_uptr)(align) - 1))
#define EPP_ALIGNMENT 64


typedef enum
{
    epp_ExecModeVDMA_off,
    epp_ExecModeVDMA_src,
    epp_ExecModeVDMA_dst,
    epp_ExecModeVDMA_all,
} epp_ExecMode;


typedef enum
{
    epp_RoundNearestEven,
    epp_RoundFloor,
    epp_RoundCeil,
    epp_RoundTruncate,
    epp_RoundNearestInf,
} epp_RoundMode;


typedef enum
{
    epp_L2DataCacheSize_0 = 0, // 0 Kb
    epp_L2DataCacheSize_1 = 1, // 128 Kb
    epp_L2DataCacheSize_2 = 2, // 256 Kb
    epp_L2DataCacheSize_3 = 3, // 512 Kb
} epp_L2DataCacheSize;


typedef enum
{
    epp_L1DataCachePFN_0 = 0, // off
    epp_L1DataCachePFN_1 = 1, // 1 line
    epp_L1DataCachePFN_2 = 2, // 2 lines
    epp_L1DataCachePFN_3 = 3, // 4 lines
    epp_L1DataCachePFN_4 = 4, // 8 lines
    epp_L1DataCachePFN_5 = 5, // 16 lines
    epp_L1DataCachePFN_6 = 6, // 32 lines
    epp_L1DataCachePFN_7 = 7, // 64 lines
} epp_L1DataCachePFN;


typedef enum
{
    /* errors */
    epp_StsBadSpec                 = -13,  /* Incorrect Spec structure */
    epp_StsL1DataCachePFNErr       = -12,  /* Unsupported size of L1D prefetch lines */
    epp_StsL2DataCacheSizeErr      = -11,  /* Unsupported size of L2D cache */
    epp_StsExecContextResourceErr  = -10,  /* Not enough resource for the operation */
    epp_StsExecContextModeErr      =  -9,  /* Unsupported mode of execution context */
    epp_StsInterpolationModeErr    =  -8,  /* Unsupported interpolation mode */
    epp_StsRoundModeErr            =  -7,  /* Unsupported round mode */
    epp_StsOutOfRangeErr           =  -6,  /* Argument is out of range */
    epp_StsDivByZeroErr            =  -5,  /* An attempt to divide by zero */
    epp_StsMemAllocErr             =  -4,  /* Not enough memory allocated for the operation */
    epp_StsBadParamsErr            =  -3,  /* Function arg/param is bad */
    epp_StsUnknownStatusErr        =  -2,  /* Bad status */  
    epp_StsUnspecifiedErr          =  -1,  /* Unspecified error */
    /* no errors */
    epp_StsOK                      =   0,  /* No error, it's OK */
    /* warnings  */
    epp_StsDivByZero               =   1,  /* Zero value(s) of the divisor */
    epp_StsUnderflow               =   2,  /* Underflow occurred in the operation */
    epp_StsOverflow                =   3,  /* Overflow occurred in the operation */
    epp_StsExecContextResourceLack =   4,  /* Not enough resource for the operation, operation was performed by available way */
} epp_Status;


typedef enum
{
    epp_InterpolateNN,
    epp_InterpolateLinear,
    epp_InterpolateSS,
} epp_InterpolationMode;


typedef enum
{
    EPP_DFT_DIV_FWD_SIZE = 1,
    EPP_DFT_DIV_INV_SIZE = 2,
    EPP_DFT_DIV_SQRTSIZE = 4,
    EPP_DFT_NODIV        = 8,
} epp_DFT_flags;


typedef struct DFTSpec epps_DFTSpec;


#pragma pack(push, 1)

typedef struct
{
    const char* name;
    const char *arch;
    const char *cpu;
    const char* ver;
    const char* hash;
    const char* date;
} epp_LibraryVersion;


typedef struct
{
    epp_s16 im;
    epp_s16 re;
} epp_cs16;


typedef struct
{
    epp_s32 im;
    epp_s32 re;
} epp_cs32;


typedef struct
{
    epp_s64 im;
    epp_s64 re;
} epp_cs64;


typedef struct
{
    epp_f16 im;
    epp_f16 re;
} epp_cf16;


typedef struct
{
    epp_f32 im;
    epp_f32 re;
} epp_cf32;


typedef struct
{
    epp_f64 im;
    epp_f64 re;
} epp_cf64;


typedef struct
{
    epp_u8* ptr;
    epp_size size;
} epp_ExecResource;


typedef struct
{
    epp_ExecMode mode;
    epp_ExecResource resource[2];
    epp_bool vdma_memory_is_cached;
} epp_ExecContext;


typedef struct
{
    epp_u32 core_id : 4;
    epp_u32 cluster_id : 4;
    epp_u32 num_cores_in_cluster : 4;
    epp_u32 num_clusters : 4;
    epp_u32 subrevision : 8;
    epp_u32 revision : 8;
} epp_CpuInfo;

#pragma pack(pop)


#ifdef __cplusplus
}
#endif
