/*
//
//       Elvees Performance Platform
//           image processing
//
*/

#pragma once

#include "eppi.h"

namespace eppi
{

/*
//  Name:        Copy
//  Purpose:     Copies image data
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
static inline epp_Status Copy_C1(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_Copy_u8_C1(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status Copy_C1C3(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_Copy_u8_C1C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status Copy_C3C1(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_Copy_u8_C3C1(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status Copy_C3P3(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* const pDst[3], const epp_s32 dstStep[3], epp_size width, epp_size height)
{
     return eppi_Copy_u8_C3P3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status Copy_P3C3(const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_Copy_u8_P3C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status Copy_C3(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
    return eppi_Copy_u8_C3(pSrc, srcStep, pDst, dstStep, width * 3, height);
}

static inline epp_Status Copy_C4(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
    return eppi_Copy_u8_C4(pSrc, srcStep, pDst, dstStep, width * 4, height);
}


/*
//  Name:        Set
//  Purpose:     Sets image data
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    val        Value(s) to set
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
static inline epp_Status Set_C1(epp_u8 val, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_Set_u8_C1(val, pDst, dstStep, width, height);
}

static inline epp_Status Set_C3(const epp_u8 val[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_Set_u8_C3(val, pDst, dstStep, width, height);
}

static inline epp_Status Set_C4(const epp_u8 val[4], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_Set_u8_C4(val, pDst, dstStep, width, height);
}

static inline epp_Status Set_C1C3(epp_u8 val, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_Set_u8_C1C3(val, pDst, dstStep, width, height);
}

static inline epp_Status Set_C1C4(epp_u8 val, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_Set_u8_C1C4(val, pDst, dstStep, width, height);
}


/*
//  Name:        Duplicate_u8_C1C3
//  Purpose:     Duplicates C1 image in all channels of C3 image
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image
//    srcStep    Step through the source image
//    pDst       Pointer to the destination image(s)
//    dstStep    Step through the destination image(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
static inline epp_Status Duplicate_C1C3(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_Duplicate_u8_C1C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status Duplicate_C1P3(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* const pDst[3], const epp_s32 dstStep[3], epp_size width, epp_size height)
{
     return eppi_Duplicate_u8_C1P3(pSrc, srcStep, pDst, dstStep, width, height);
}


/*
//  Name:        ColorConversion
//  Purpose:     Performs Color conversion
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
static inline epp_Status YPbPr444_RGB_BT601_P3C3(const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YPbPr444_RGB_BT601_u8_P3C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YPbPr422_RGB_BT601_P3C3(const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YPbPr422_RGB_BT601_u8_P3C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YPbPr420_RGB_BT601_P3C3(const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YPbPr420_RGB_BT601_u8_P3C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YPbPrVUYA_RGBA_BT601_AC4(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YPbPrVUYA_RGBA_BT601_u8_AC4(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YPbPrYUYV_RGB_BT601_C2C3(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YPbPrYUYV_RGB_BT601_u8_C2C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YPbPrNV12_RGB_BT601_P2C3(const epp_u8* const pSrc[2], const epp_s32 srcStep[2], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YPbPrNV12_RGB_BT601_u8_P2C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YCbCr444_RGBs_BT601_P3C3(const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YCbCr444_RGBs_BT601_u8_P3C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YCbCr422_RGBs_BT601_P3C3(const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YCbCr422_RGBs_BT601_u8_P3C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YCbCr420_RGBs_BT601_P3C3(const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YCbCr420_RGBs_BT601_u8_P3C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YCbCrVUYA_RGBAs_BT601_AC4(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YCbCrVUYA_RGBAs_BT601_u8_AC4(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YCbCrYUYV_RGBs_BT601_C2C3(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YCbCrYUYV_RGBs_BT601_u8_C2C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YCbCrNV12_RGBs_BT601_P2C3(const epp_u8* const pSrc[2], const epp_s32 srcStep[2], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YCbCrNV12_RGBs_BT601_u8_P2C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YPbPr444_RGB_BT2020_P3C3(const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YPbPr444_RGB_BT2020_u8_P3C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YPbPr422_RGB_BT2020_P3C3(const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YPbPr422_RGB_BT2020_u8_P3C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YPbPr420_RGB_BT2020_P3C3(const epp_u8* const pSrc[3], const epp_s32 srcStep[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YPbPr420_RGB_BT2020_u8_P3C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YPbPrVUYA_RGBA_BT2020_AC4(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YPbPrVUYA_RGBA_BT2020_u8_AC4(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YPbPrYUYV_RGB_BT2020_C2C3(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YPbPrYUYV_RGB_BT2020_u8_C2C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status YPbPrNV12_RGB_BT2020_P2C3(const epp_u8* const pSrc[2], const epp_s32 srcStep[2], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_YPbPrNV12_RGB_BT2020_u8_P2C3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status RGB_YPbPr444_BT2020_C3P3(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* const pDst[3], const epp_s32 dstStep[3], epp_size width, epp_size height)
{
     return eppi_RGB_YPbPr444_BT2020_u8_C3P3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status RGB_YPbPr422_BT2020_C3P3(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* const pDst[3], const epp_s32 dstStep[3], epp_size width, epp_size height)
{
     return eppi_RGB_YPbPr422_BT2020_u8_C3P3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status RGB_YPbPr420_BT2020_C3P3(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* const pDst[3], const epp_s32 dstStep[3], epp_size width, epp_size height)
{
     return eppi_RGB_YPbPr420_BT2020_u8_C3P3(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status RGBA_YPbPrVUYA_BT2020_AC4(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_RGBA_YPbPrVUYA_BT2020_u8_AC4(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status RGB_YPbPrYUYV_BT2020_C3C2(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_RGB_YPbPrYUYV_BT2020_u8_C3C2(pSrc, srcStep, pDst, dstStep, width, height);
}

static inline epp_Status RGB_YPbPrNV12_BT2020_C3P2(const epp_u8* pSrc, epp_s32 srcStep, epp_u8* const pDst[3], const epp_s32 dstStep[3], epp_size width, epp_size height)
{
     return eppi_RGB_YPbPrNV12_BT2020_u8_C3P2(pSrc, srcStep, pDst, dstStep, width, height);
}


/*
//  Name:        Resize
//  Purpose:     Resizes image
//  Context:
//  Returns:     epp_Status
//    epp_StsOK                    OK
//    epp_StsInterpolationModeErr  Wrong interpolation mode
//  Parameters:
//    pSrc           Pointer to the source image (multichannel or planes)
//    srcStep        Step through the source image(s)
//    srcWidth       The width of source image.
//    srcHeight      The height of source image.
//    pDst           Pointer to the destination image (multichannel or planes)
//    dstStep        Step through the destination image(s)
//    dstWidth       The width of destination image.
//    dstHheight     The height of destination image.
//    interpolation  Interpolation mode.
//    pBuffer        Pointer to the external buffer.
//  Notes:
*/
static inline epp_Status Resize_C1(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep, epp_size dstWidth, epp_size dstHeight, epp_InterpolationMode interpolation, void* pBuffer)
{
     return eppi_Resize_u8_C1(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep, dstWidth, dstHeight, interpolation, pBuffer);
}

static inline epp_Status Resize_C3(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep, epp_size dstWidth, epp_size dstHeight, epp_InterpolationMode interpolation, void* pBuffer)
{
     return eppi_Resize_u8_C3(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep, dstWidth, dstHeight, interpolation, pBuffer);
}


/*
//  Name:        Histogram
//  Purpose:     Computes image histogram
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image(s)
//    srcStep    Step through the source image(s)
//    pHist      Pointer to the destination histogram(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
static inline epp_Status Histogram_C1(const epp_u8* pSrc, epp_s32 srcStep, epp_u32 pHist[256], epp_size width, epp_size height)
{
     return eppi_Histogram_u8_C1(pSrc, srcStep, pHist, width, height);
}

static inline epp_Status Histogram_C3(const epp_u8* pSrc, epp_s32 srcStep, epp_u32 pHist[3*256], epp_size width, epp_size height)
{
     return eppi_Histogram_u8_C3(pSrc, srcStep, pHist, width, height);
}


/*
//  Name:        CumulativeHistogram
//  Purpose:     Computes cumulative image histogram from normal histogram
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pHist      Pointer to the source normal histogram
//    pHistC     Pointer to the destination cumulative histogram
//  Notes:
*/
static inline epp_Status CumulativeHistogram(const epp_u32 pHist[256], epp_u32 pHistC[256])
{
     return eppi_CumulativeHistogram_u8_C1(pHist, pHistC);
}


/*
//  Name:        EqualizeHistogram
//  Purpose:     Computes equalized image histogram from normal histogram and LUT for transform
//  Context:
//  Returns:     epp_Status
//    epp_StsOK            OK
//    epp_StsDivByZeroErr  if all values in normal histogram are zero
//  Parameters:
//    pHist      Pointer to the source normal histogram
//    pHistE     Pointer to the destination equalized histogram (if it is not equal to NULL)
//    pLUT       Pointer to the destination lookup table for transform
//  Notes:
*/
static inline epp_Status EqualizeHistogram8(const epp_u32 pHist[256], epp_u32 pHistE[256], epp_u8 pLUT[256])
{
     return eppi_EqualizeHistogram_u8_C1(pHist, pHistE, pLUT);
}


/*
//  Name:        eppi_LUT
//  Purpose:     Performs intensity transformation using lookup table(s)
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    pLUT       Pointer to lookup table(s)
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
static inline epp_Status LUT_C1(const epp_u8* pSrc, epp_s32 srcStep, const epp_u8 pLUT[256], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_LUT_u8_C1(pSrc, srcStep, pLUT, pDst, dstStep, width, height);
}

static inline epp_Status LUT_C3(const epp_u8* pSrc, epp_s32 srcStep, const epp_u8 pLUT[3*256], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_LUT_u8_C3(pSrc, srcStep, pLUT, pDst, dstStep, width, height);
}


/*
//  Name:        MulCAddC
//  Purpose:     Multiplicates image pixels by value and add another value
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    vMul       Value to multiplicate
//    vAdd       Value to add
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
static inline epp_Status MulCAddC_C1(const epp_u8* pSrc, epp_s32 srcStep, epp_f32 vMul, epp_f32 vAdd, epp_f32* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_MulCAddC_u8f32_C1(pSrc, srcStep, vMul, vAdd, pDst, dstStep, width, height);
}

static inline epp_Status MulCAddC_C3(const epp_u8* pSrc, epp_s32 srcStep, const epp_f32 vMul[3], const epp_f32 vAdd[3], epp_f32* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_MulCAddC_u8f32_C3(pSrc, srcStep, vMul, vAdd, pDst, dstStep, width, height);
}

static inline epp_Status MulCAddC_C3P3(const epp_u8* pSrc, epp_s32 srcStep, const epp_f32 vMul[3], const epp_f32 vAdd[3], epp_f32* const pDst[3], const epp_s32 dstStep[3], epp_size width, epp_size height)
{
     return eppi_MulCAddC_u8f32_C3P3(pSrc, srcStep, vMul, vAdd, pDst, dstStep, width, height);
}


/*
//  Name:        eppi_AddC
//  Purpose:     Adds value to image pixels
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    vAdd       Value(s) to add
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
static inline epp_Status AddC_C1S(const epp_u8* pSrc, epp_s32 srcStep, epp_u8 vAdd, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_AddC_u8_C1S(pSrc, srcStep, vAdd, pDst, dstStep, width, height);
}

static inline epp_Status AddC_C3S(const epp_u8* pSrc, epp_s32 srcStep, const epp_u8 vAdd[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_AddC_u8_C3S(pSrc, srcStep, vAdd, pDst, dstStep, width, height);
}


/*
//  Name:        eppi_SubC
//  Purpose:     Subtracts value from image pixels
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    vSub       Value(s) to subtract
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//    width      The width of images.
//    height     The height of images.
//  Notes:
*/
static inline epp_Status SubC_C1S(const epp_u8* pSrc, epp_s32 srcStep, epp_u8 vSub, epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_SubC_u8_C1S(pSrc, srcStep, vSub, pDst, dstStep, width, height);
}

static inline epp_Status SubC_C3S(const epp_u8* pSrc, epp_s32 srcStep, const epp_u8 vSub[3], epp_u8* pDst, epp_s32 dstStep, epp_size width, epp_size height)
{
     return eppi_SubC_u8_C3S(pSrc, srcStep, vSub, pDst, dstStep, width, height);
}


/*
//  Name:        Rotate
//  Purpose:     Rotates image by 90, 180, 270 degree counterclockwise
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    srcWidth   The width of source image.
//    srcHeight  The height of source image.
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//  Notes:
*/
static inline epp_Status Rotate90_C1(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_Rotate90_u8_C1(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status Rotate90_C3(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_Rotate90_u8_C3(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status Rotate90_C4(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_Rotate90_u8_C4(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status Rotate180_C1(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_Rotate180_u8_C1(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status Rotate180_C3(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_Rotate180_u8_C3(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status Rotate180_C4(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_Rotate180_u8_C4(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status Rotate270_C1(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_Rotate270_u8_C1(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status Rotate270_C3(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_Rotate270_u8_C3(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status Rotate270_C4(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_Rotate270_u8_C4(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}


/*
//  Name:        Mirror
//  Purpose:     Mirrors image about horizontal or vertical axis, or both
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    srcWidth   The width of source image.
//    srcHeight  The height of source image.
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//  Notes:
*/
static inline epp_Status MirrorH_C1(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_MirrorH_u8_C1(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status MirrorH_C3(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_MirrorH_u8_C3(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status MirrorH_C4(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_MirrorH_u8_C4(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status MirrorV_C1(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_MirrorV_u8_C1(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status MirrorV_C3(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_MirrorV_u8_C3(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status MirrorV_C4(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_MirrorV_u8_C4(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status MirrorHV_C1(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_MirrorHV_u8_C1(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status MirrorHV_C3(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_MirrorHV_u8_C3(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status MirrorHV_C4(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_MirrorHV_u8_C4(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}


/*
//  Name:        Transpose
//  Purpose:     Transposes image
//  Context:
//  Returns:     epp_Status
//    epp_StsOK  OK
//  Parameters:
//    pSrc       Pointer to the source image (multichannel or planes)
//    srcStep    Step through the source image(s)
//    srcWidth   The width of source image.
//    srcHeight  The height of source image.
//    pDst       Pointer to the destination image (multichannel or planes)
//    dstStep    Step through the destination image(s)
//  Notes:
*/
static inline epp_Status Transpose_C1(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_Transpose_u8_C1(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status Transpose_C3(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_Transpose_u8_C3(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}
static inline epp_Status Transpose_C4(const epp_u8* pSrc, epp_s32 srcStep, epp_size srcWidth, epp_size srcHeight, epp_u8* pDst, epp_s32 dstStep)
{
     return eppi_Transpose_u8_C4(pSrc, srcStep, srcWidth, srcHeight, pDst, dstStep);
}

} // namespace eppi
